@@ -80,13 +80,13 @@ class TestEdgeSmtp(MoxTestBase):
     def test_mail_rcpt_data_rset(self):
         mock = self.mox.CreateMockAnything()
         mock.__call__(IsA(SmtpSession)).AndReturn(mock)
-        mock.handle_mail(IsA(Reply), 'sender@example.com')
-        mock.handle_rcpt(IsA(Reply), 'rcpt@example.com')
+        mock.handle_mail(IsA(Reply), 'sender@example.com', {})
+        mock.handle_rcpt(IsA(Reply), 'rcpt@example.com', {})
         mock.handle_data(IsA(Reply))
         self.mox.ReplayAll()
         h = SmtpSession(None, mock, None)
-        h.MAIL(Reply('250'), 'sender@example.com')
-        h.RCPT(Reply('250'), 'rcpt@example.com')
+        h.MAIL(Reply('250'), 'sender@example.com', {})
+        h.RCPT(Reply('250'), 'rcpt@example.com', {})
         self.assertEqual('sender@example.com', h.envelope.sender)
         self.assertEqual(['rcpt@example.com'], h.envelope.recipients)
         h.DATA(Reply('550'))
